bayespy.inference.vmp.nodes.deterministic.Deterministic.plates
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. autoattribute:: Deterministic.plates